@@ -88,7 +88,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
         django_many_to_many_params,
 ):
     need_to_create = True
-    if django_id != 'null':
+    if django_id not in ['null', None]:
         if django_model.objects.filter(id=django_id):
             need_to_create = False
 
@@ -96,7 +96,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
 
     if need_to_create:
         pass
-    #     print(need_to_create, django_params, django_many_to_many_params)
+        print(need_to_create, django_params, django_many_to_many_params)
     #     django_instance = django_model.objects.create(**django_params)
     #     update_django_many_to_many(
     #         django_model,
@@ -115,7 +115,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
             django_instance_fields_value = getattr(django_instance, redis_field_name)
             if django_instance_fields_value != redis_field_value:
                 changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
-    #     print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
+        print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
     #     django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
     #     update_django_many_to_many(
     #         django_model,
@@ -140,18 +140,19 @@ async def async_redis_dict_to_django_params(
             if django_field_data['class'] == django_models.ForeignKey:
                 foreign_key_model = django_field_data['remote_field_model']
                 redis_foreign_key_instance = redis_dict[django_field_name]
-                print(django_field_name, redis_foreign_key_instance)
-                print('foreign_key', redis_foreign_key_instance)
-                django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
-                    redis_foreign_key_instance,
-                    foreign_key_model,
-                )
-                django_params[django_field_name] = django_foreign_key_instance
+                if redis_foreign_key_instance not in ['null', None]:
+                    django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
+                        redis_foreign_key_instance,
+                        foreign_key_model,
+                    )
+                    django_params[django_field_name] = django_foreign_key_instance
+                else:
+                    django_params[django_field_name] = None
             elif django_field_data['class'] == django_models.ManyToManyField:
                 many_to_many_model = django_field_data['remote_field_model']
                 django_many_to_many_instances = []
                 redis_many_to_many_instances = redis_dict[django_field_data['name']]
-                if redis_many_to_many_instances != 'null':
+                if redis_many_to_many_instances not in ['null', None] and redis_many_to_many_instances:
                     for redis_many_to_many_instance in redis_many_to_many_instances:
                         django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
                             redis_many_to_many_instance,
@@ -383,7 +384,6 @@ async def django_instance_field_to_redis_value(
             redis_value = None
         else:
             django_foreign_key_instance = django_field_value
-
             if save_related_models:
                 redis_foreign_key_instance = await get_or_create_redis_instance_from_django_instance(
                     django_foreign_key_instance,
