@@ -75,6 +75,8 @@ class RedisString(RedisField):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = f'{value}'
+        else:
+            value = None
         return value
 
 
@@ -97,7 +99,7 @@ class RedisNumber(RedisField):
             else:
                 check_types(value, (int, float))
         else:
-            value = 0
+            value = None
         return value
 
 
@@ -124,6 +126,8 @@ class RedisDateTime(RedisString):
             value = super().deserialize_value(value, redis_root)
             check_types(value, str)
             value = datetime.datetime.strptime(value, '%Y.%m.%d-%H:%M:%S+%Z')
+        else:
+            value = None
         return value
 
 
@@ -163,6 +167,8 @@ class RedisForeignKey(RedisNumber):
             model_name = self.model.__name__
             instance_id = value
             value = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')[instance_id]
+        else:
+            value = None
         return value
 
 
@@ -190,6 +196,8 @@ class RedisJson(RedisField):
             check_types(value, str)
             value = json.loads(value)
             check_types(value, self.json_allowed_types)
+        else:
+            value = None
         return value
 
 
@@ -204,6 +212,8 @@ class RedisDict(RedisJson):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
+        else:
+            value = None
         return value
 
 
@@ -218,6 +228,8 @@ class RedisList(RedisJson):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
+        else:
+            value = None
         return value
 
 
@@ -241,19 +253,21 @@ class RedisManyToMany(RedisList):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
-            check_types(value, list)
             model_name = self.model.__name__
             isntances_ids = value
             instances_list = []
             for instance_id in isntances_ids:
-                instance = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')
-                instances_list.append(instance)
+                instances = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')
+                if len(instances.keys()):
+                    instance = instances[instance_id]
+                    instances_list.append(instance)
             value = instances_list
+
         return value
 
 
 class RedisBool(RedisNumber):
-    
+
     def __init__(self, *args, **kwargs):
         kwargs['choices'] = {True: 'Yes', False: 'No'}
         super().__init__(*args, **kwargs)
@@ -263,7 +277,7 @@ class RedisBool(RedisNumber):
         if self.value not in [None, 'null']:
             check_types(self.value, bool)
             self.value = int(self.value)
-        return super().clean()    
+        return super().clean()
 
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
@@ -273,7 +287,7 @@ class RedisBool(RedisNumber):
         return value
 
 
-class RedisDecimal(RedisNumber):
+class RedisDecimal(RedisString):
 
     def clean(self):
         self.value = self.check_value()
@@ -286,6 +300,8 @@ class RedisDecimal(RedisNumber):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = decimal.Decimal(value)
+        else:
+            value = None
         return value
 
 
@@ -305,6 +321,8 @@ class RedisDate(RedisString):
             value = super().deserialize_value(value, redis_root)
             check_types(value, str)
             value = datetime.datetime.strptime(value, '%Y.%m.%d+%Z').date()
+        else:
+            value = None
         return value
 
 # class RedisDjangoForeignKey(RedisNumber):
